def CalUncer(data_list):
    data_num = len(data_list)
    data_sum=sum(data_list)
    data_Average=data_sum/data_num
    L2_sum=0
    for data in data_list:
        L2_sum+=(data-data_Average)**2
    Ua=(L2_sum/(data_num*data_num-1))**0.5
    E=Ua/data_Average
    print("+--------------------------------------+")
    print("|  平均值是:     \t"+str(data_Average))
    print("|  A类不确定度是: \t"+str(Ua))
    print("|  相对不确定度是: \t"+str(E*100)+"%")
    print("+--------------------------------------+")



def AveDevCalTab(x_list,y_list):
    DEV=[]
    DEV.append(y_list)
    N=len(x_list)
    for jie in range(1,N):
        n=len(DEV[jie-1])
        dev=[]
        for i in range(n):
            if(i<jie):
                dev.append(0)
            else:
                ave_dev = (DEV[jie - 1][i] - DEV[jie - 1][i - 1]) / (x_list[i] - x_list[i - jie])
                dev.append(ave_dev)
        DEV.append(dev)
    print("均差计算表如下:")
    print("|{:^12}|{:^12}".format("X","Y"),end="|")
    for i in range(1,N):
        print("{:^12}|".format("N"+str(i)),end="")
    print("")
    for i in range(N):
        print("|",end="")
        print("{:^12.5f}".format(x_list[i]),end="|")
        for j in range(N):
            print("{:^12.5f}".format(DEV[j][i]),end="|")
        print("")

def NewtonChaZHi(x_list,y_list,x):
    DEV=[]
    DEV.append(y_list)
    N=len(x_list)
    for jie in range(1,N):
        n=len(DEV[jie-1])
        dev=[]
        for i in range(n):
            if(i<jie):
                dev.append(0)
            else:
                ave_dev = (DEV[jie - 1][i] - DEV[jie - 1][i - 1]) / (x_list[i] - x_list[i - jie])
                dev.append(ave_dev)
        DEV.append(dev)
    y=0
    for i in range(N):
        a=DEV[i][i]
        p=1
        for j in range(i):
            p*=(x-x_list[j])
        y+=a*p
    return y



